@@ -4,7 +4,7 @@ from typing import List
 from PIL import Image
 
 from .structures import *
-from .remote.rustplus_pb2 import *
+from .remote.rustplus_proto import *
 from .remote import RustRemote, HeartBeat
 from ..commands import CommandOptions
 from ..exceptions import *
@@ -17,7 +17,7 @@ class BaseRustSocket:
         ip: str = None,
         port: str = None,
         steam_id: int = None,
-        playerToken: int = None,
+        player_token: int = None,
         command_options: CommandOptions = None,
         raise_ratelimit_exception: bool = True,
         ratelimit_limit: int = 25,
@@ -32,13 +32,13 @@ class BaseRustSocket:
             raise ValueError("Port cannot be None")
         if steam_id is None:
             raise ValueError("SteamID cannot be None")
-        if playerToken is None:
+        if player_token is None:
             raise ValueError("PlayerToken cannot be None")
 
         self.ip = ip
         self.port = port
         self.steam_id = steam_id
-        self.player_token = playerToken
+        self.player_token = player_token
         self.seq = 1
         self.command_options = command_options
         self.raise_ratelimit_exception = raise_ratelimit_exception
@@ -93,7 +93,7 @@ class BaseRustSocket:
 
         return app_request
 
-    async def connect(self, retries: int = float("inf")) -> None:
+    async def connect(self, retries: int = float("inf"), delay: int = 20) -> None:
         """
         Attempts to open a connection to the rust game server specified in the constructor
 
@@ -101,7 +101,7 @@ class BaseRustSocket:
         """
         try:
             if self.remote.ws is None:
-                self.remote.connect(retries=retries)
+                self.remote.connect(retries=retries, delay=delay)
                 await self.send_wakeup_request()
                 await self.heartbeat.start_beat()
         except ConnectionRefusedError:
@@ -203,17 +203,35 @@ class BaseRustSocket:
             if isinstance(coro, RegisteredListener):
                 coro = coro.get_coro()
 
+            async def get_entity(self, eid) -> RustEntityInfo:
+
+                await self._handle_ratelimit()
+
+                app_request = self._generate_protobuf()
+                app_request.entityId = eid
+                app_request.getEntityInfo.CopyFrom(AppEmpty())
+
+                await self.remote.send_message(app_request)
+
+                return await self.remote.get_response(
+                    app_request.seq, app_request, False
+                )
+
             def entity_event_callback(future_inner: Future):
-                try:
-                    entity_info: RustEntityInfo = future_inner.result()
-                    self.remote.event_handler.register_event(
-                        RegisteredListener(eid, (coro, loop, entity_info.type))
-                    )
-                except Exception:
+
+                entity_info = future_inner.result()
+
+                if entity_info.response.HasField("error"):
                     raise SmartDeviceRegistrationError("Not Found")
 
+                self.remote.event_handler.register_event(
+                    RegisteredListener(
+                        eid, (coro, loop, entity_info.response.entityInfo.type)
+                    )
+                )
+
             loop = asyncio.get_event_loop()
-            future = asyncio.run_coroutine_threadsafe(self.get_entity_info(eid), loop)
+            future = asyncio.run_coroutine_threadsafe(get_entity(self, eid), loop)
             future.add_done_callback(entity_event_callback)
 
             return RegisteredListener(eid, (coro))
